@@ -70,6 +70,18 @@ pub trait Parser: SexprFactory {
 
         Ok(sexpr)
     }
+
+    fn parse_seq<'i>(&mut self, input: &'i str) -> Result<'i, Self::Sexpr> {
+        let mut token_stream = Tokenizer::new(input);
+
+        let mut exprs = vec![];
+
+        while token_stream.peek_token().is_some() {
+            exprs.push(parse_expr(self, &mut token_stream)?);
+        }
+
+        Ok(self.list(exprs))
+    }
 }
 
 impl<T: SexprFactory> Parser for T {}
@@ -78,6 +90,10 @@ pub fn parse<S: Default + Parser>(input: &str) -> Result<S::Sexpr> {
     S::default().parse(input)
 }
 
+pub fn parse_seq<S: Default + Parser>(input: &str) -> Result<S::Sexpr> {
+    S::default().parse_seq(input)
+}
+
 fn parse_expr<'i, S: SexprFactory + ?Sized>(
     factory: &mut S,
     token_stream: &mut Tokenizer<'i>,
@@ -407,6 +423,15 @@ mod tests {
         )
     }
 
+    #[test]
+    fn multiple_exprs() {
+        assert_eq!(SF.parse_seq(" "), Ok(SF.list(vec![])));
+        assert_eq!(
+            SF.parse_seq("1 2 3"),
+            Ok(SF.list(vec![S::Int(1), S::Int(2), S::Int(3)]))
+        );
+    }
+
     #[test]
     fn stateful_factory() {
         #[derive(Debug, PartialEq)]
